@@ -22,19 +22,22 @@ class AuthorisationManager:
         self._service_name = service_name
         self._jwt_verifier = okta_jwt_verifier.BaseJWTVerifier(issuer=okta_issuer, audience=okta_audience)
 
-    async def is_user_authorised(self, allowed_groups: list, resource_name: str, cookies: Mapping) -> bool:
+    async def _verify_token(self, cookies: Mapping):
         try:
-            access_token = cookies["access_token"]
-        except KeyError:
-            raise InvalidTokenException("No token provided!")
-
-        try:
-            await self._jwt_verifier.verify_access_token(access_token)
+            await self._jwt_verifier.verify_access_token(cookies["oktagon_access_token"])
         except JWTValidationException as exc:
             logger.error("Failed to validate access token: %s", exc)
             raise InvalidTokenException from JWTValidationException
+        except KeyError:
+            raise InvalidTokenException("No token provided!")
 
-        decoded_claims = self._jwt_verifier.parse_token(access_token)[1]
+    async def get_user_email(self, cookies: Mapping) -> str:
+        await self._verify_token(cookies)
+        return self._jwt_verifier.parse_token(cookies["oktagon_access_token"])[1]["sub"]
+
+    async def is_user_authorised(self, allowed_groups: list, resource_name: str, cookies: Mapping) -> bool:
+        await self._verify_token(cookies)
+        decoded_claims = self._jwt_verifier.parse_token(cookies["oktagon_access_token"])[1]
 
         try:
             return self.does_user_have_required_group(
